# theng

This Python package, provided by [Thunderhead Engineering](https://thunderheadeng.com), is useful for post-processing of data from several life-safety simulators.
The package currently supports the following simulators:

- [PyroSim](https://www.thunderheadeng.com/pyrosim/) / [FDS](https://github.com/firemodels/fds)
- [Pathfinder](https://www.thunderheadeng.com/pathfinder/)

You can read the full docs on the [theng Documentation Site](https://thunderheadeng.gitlab.io/sandbox/theng/index.html).

## Attribution

This package uses the [fdsreader](https://github.com/FireDynamics/fdsreader) module, developed by the folks at [Julich](https://fz-juelich.de).
We thank the developers for their hard work on making this package so easy to work with.